import re

def glue_it(templateString, dictionaryToMatch):
    pattern = re.compile(r'\{\{([^}$]*)\}\}')
    number_of_patterns_found = len(pattern.findall(templateString))
     
    for i in range(number_of_patterns_found):
        val = pattern.search(templateString).groups()[0]
        if val in dictionaryToMatch:
            templateString = templateString.replace('{{'+val+'}}',dictionaryToMatch[val])
        else:
            templateString = templateString.replace('{{'+val+'}}',dictionaryToMatch['default'])            
    return templateString




from distutils.core import setup
setup(
    name='gluestring',
    packages=['gluestring'],
    version='0.1',
    license='MIT',
    description='Easy way to create template strings',
    author='Aananya',
    author_email='astream.h@outlook.com',
    url='https://github.com/aananya27/gluestring',
    download_url='https://github.com/aananya27/gluestring/archive/v_01.tar.gz',
    keywords=['template', 'string-formatter', 'util'],
    install_requires=[
        're',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7'
    ],
)
